@@ -488,11 +488,11 @@ class MySqlPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpenabl
         if sort:
             query += " ORDER BY " + sort
 
+        query += " LIMIT " + str(take)
+        
         if skip >= 0:
             query += " OFFSET " + str(skip)
 
-        query += " LIMIT " + str(take)
-
         result = self._request(query)
         items = result['items']
 
@@ -548,7 +548,7 @@ class MySqlPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpenabl
         :return: a data list
         """
 
-        select = select if len(select) > 0 else '*'
+        select = select if select and len(select) > 0 else '*'
         query = "SELECT " + select + " FROM " + self._quoted_table_name()
         if filter and filter != '':
             query += " WHERE " + filter
@@ -556,7 +556,8 @@ class MySqlPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpenabl
         if sort:
             query += " ORDER BY " + sort
 
-        items = self._request(query)
+        result = self._request(query)
+        items = result['items']
 
         if items:
             self._logger.trace(correlation_id, "Retrieved %d from %s", len(items), self._table_name)
@@ -588,8 +589,10 @@ class MySqlPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpenabl
             query += " WHERE " + filter
 
         count = len(result['items'][0]) if result['items'] and len(result['items']) == 1 else 0
-        pos = random.randint(0, count - 1)
-        query += f" OFFSET {pos} LIMIT 1"
+        count = 0 if count == 0 else count - 1 
+        
+        pos = random.randint(0, count)
+        query += f" LIMIT 1 OFFSET {pos}"
 
         result = self._request(query)
         item = result['items'][0] if result['items'] is not None and len(result['items']) > 0 else None
